==> ae_sideloading_server-0.1.8.tar.gz: ae_sideloading_server-0.1.8/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# sideloading_server portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_sideloading_server/master?logo=python)](
    https://gitlab.com/ae-group/ae_sideloading_server)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_sideloading_server)](
    https://pypi.org/project/ae-sideloading-server/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_sideloading_server/coverage.svg)](
    https://ae-group.gitlab.io/ae_sideloading_server/coverage/ae_sideloading_server_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_sideloading_server/mypy.svg)](
    https://ae-group.gitlab.io/ae_sideloading_server/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_sideloading_server/pylint.svg)](
    https://ae-group.gitlab.io/ae_sideloading_server/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_sideloading_server)](
    https://pypi.org/project/ae-sideloading-server/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_sideloading_server)](
    https://pypi.org/project/ae-sideloading-server/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_sideloading_server)](
    https://pypi.org/project/ae-sideloading-server/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_sideloading_server)](
    https://pypi.org/project/ae-sideloading-server/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_sideloading_server)](
    https://libraries.io/pypi/ae-sideloading-server)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_sideloading_server)](
    https://pypi.org/project/ae-sideloading-server/#files)


## installation


Execute the following command for to use the ae.sideloading_server module in your
application. It will install ae.sideloading_server into your python (virtual) environment:
 
```shell script
pip install ae-sideloading-server
```

If you instead want to contribute to this portion then first fork
[the ae_sideloading_server repository at GitLab](https://gitlab.com/ae-group/ae_sideloading_server "ae.sideloading_server code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_sideloading_server):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.sideloading_server.html#module-ae.sideloading_server
"ae_sideloading_server documentation").

<!-- Common files version 0.1.66 deployed version 0.1.0 (with 0.1.66)
     to https://gitlab.com/ae-group as ae_sideloading_server module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-sideloading-server as namespace portion ae-sideloading-server.
-->

==> ae_sideloading_server-0.2.8.tar.gz: ae_sideloading_server-0.2.8/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
-->
# sideloading_server portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_sideloading_server/master?logo=python)](
    https://gitlab.com/ae-group/ae_sideloading_server)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_sideloading_server)](
    https://pypi.org/project/ae-sideloading-server/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_sideloading_server/coverage.svg)](
    https://ae-group.gitlab.io/ae_sideloading_server/coverage/ae_sideloading_server_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_sideloading_server/mypy.svg)](
    https://ae-group.gitlab.io/ae_sideloading_server/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_sideloading_server/pylint.svg)](
    https://ae-group.gitlab.io/ae_sideloading_server/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_sideloading_server)](
    https://pypi.org/project/ae-sideloading-server/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_sideloading_server)](
    https://pypi.org/project/ae-sideloading-server/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_sideloading_server)](
    https://pypi.org/project/ae-sideloading-server/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_sideloading_server)](
    https://pypi.org/project/ae-sideloading-server/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_sideloading_server)](
    https://libraries.io/pypi/ae-sideloading-server)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_sideloading_server)](
    https://pypi.org/project/ae-sideloading-server/#files)


## installation


execute the following command to use the ae.sideloading_server module in your
application. it will install ae.sideloading_server into your python (virtual) environment:
 
```shell script
pip install ae-sideloading-server
```

if you instead want to contribute to this portion then first fork
[the ae_sideloading_server repository at GitLab](https://gitlab.com/ae-group/ae_sideloading_server "ae.sideloading_server code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_sideloading_server):

```shell script
pip install -e .[dev]
```

the last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or to extend the portion documentation.
to contribute only to the unit tests or to the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

more info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.sideloading_server.html#module-ae.sideloading_server
"ae_sideloading_server documentation").

<!-- common files version 0.2.77 deployed version 0.2.8 (with 0.2.77)
     to https://gitlab.com/ae-group as ae_sideloading_server module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-sideloading-server as namespace portion ae-sideloading-server.
-->
